boss.starter - heros-boss 0.6.10 documentation

Skip to content
Back to top
View this page

# boss.starter

## Functions

`create_unique_instance_name`(→ str) | Creates a unique instance identifier consisting of the hostname and an UUID.
`get_parser`() |
`run`([args]) |

## Module Contents

boss.starter.create_unique_instance_name() → str

  Creates a unique instance identifier consisting of the hostname and an UUID.

  Returns:

    A unique identifier.

boss.starter.get_parser()

boss.starter.run(args=None)